EXPORTS
	??0TAllowRegisterDlgRequest@@QAE@XZ @ 1 NONAME ; public: __thiscall TAllowRegisterDlgRequest::TAllowRegisterDlgRequest(void)
	??0TAllowRegisterDlgResponse@@QAE@XZ @ 2 NONAME ; public: __thiscall TAllowRegisterDlgResponse::TAllowRegisterDlgResponse(void)
	??0TAllowUnRegisterDlgRequest@@QAE@XZ @ 3 NONAME ; public: __thiscall TAllowUnRegisterDlgRequest::TAllowUnRegisterDlgRequest(void)
	??0TAllowUnRegisterDlgResponse@@QAE@XZ @ 4 NONAME ; public: __thiscall TAllowUnRegisterDlgResponse::TAllowUnRegisterDlgResponse(void)
	??0TAskSaveDlgRequest@@QAE@XZ @ 5 NONAME ; public: __thiscall TAskSaveDlgRequest::TAskSaveDlgRequest(void)
	??0TAskSaveDlgResponse@@QAE@XZ @ 6 NONAME ; public: __thiscall TAskSaveDlgResponse::TAskSaveDlgResponse(void)
	??0TAuthenticationDlgRequest@@QAE@XZ @ 7 NONAME ; public: __thiscall TAuthenticationDlgRequest::TAuthenticationDlgRequest(void)
	??0TAuthenticationDlgResponse@@QAE@XZ @ 8 NONAME ; public: __thiscall TAuthenticationDlgResponse::TAuthenticationDlgResponse(void)
	??0TSenNotPluginRequest@@QAE@H@Z @ 9 NONAME ; public: __thiscall TSenNotPluginRequest::TSenNotPluginRequest(int)
	??0TSenNotPluginRequest@@QAE@XZ @ 10 NONAME ; public: __thiscall TSenNotPluginRequest::TSenNotPluginRequest(void)
	?Method@TSenNotPluginRequest@@QAEHXZ @ 11 NONAME ; public: int __thiscall TSenNotPluginRequest::Method(void)
	?OkButtonPressed@TAllowRegisterDlgResponse@@QBEHXZ @ 12 NONAME ; public: int __thiscall TAllowRegisterDlgResponse::OkButtonPressed(void)const 
	?OkButtonPressed@TAllowUnRegisterDlgResponse@@QBEHXZ @ 13 NONAME ; public: int __thiscall TAllowUnRegisterDlgResponse::OkButtonPressed(void)const 
	?OkButtonPressed@TAskSaveDlgResponse@@QBEHXZ @ 14 NONAME ; public: int __thiscall TAskSaveDlgResponse::OkButtonPressed(void)const 
	?OkButtonPressed@TAuthenticationDlgResponse@@QBEHXZ @ 15 NONAME ; public: int __thiscall TAuthenticationDlgResponse::OkButtonPressed(void)const 
	?Password@TAuthenticationDlgRequest@@QBE?AVTPtrC16@@XZ @ 16 NONAME ; public: class TPtrC16  __thiscall TAuthenticationDlgRequest::Password(void)const 
	?Password@TAuthenticationDlgResponse@@QBE?AVTPtrC16@@XZ @ 17 NONAME ; public: class TPtrC16  __thiscall TAuthenticationDlgResponse::Password(void)const 
	?SetData@TAuthenticationDlgRequest@@QAEHABVTDesC16@@0@Z @ 18 NONAME ; public: int __thiscall TAuthenticationDlgRequest::SetData(class TDesC16 const &,class TDesC16 const &)
	?SetData@TAuthenticationDlgResponse@@QAEHABVTDesC16@@0H@Z @ 19 NONAME ; public: int __thiscall TAuthenticationDlgResponse::SetData(class TDesC16 const &,class TDesC16 const &,int)
	?SetOkButton@TAllowRegisterDlgResponse@@QAEXH@Z @ 20 NONAME ; public: void __thiscall TAllowRegisterDlgResponse::SetOkButton(int)
	?SetOkButton@TAllowUnRegisterDlgResponse@@QAEXH@Z @ 21 NONAME ; public: void __thiscall TAllowUnRegisterDlgResponse::SetOkButton(int)
	?SetOkButton@TAskSaveDlgResponse@@QAEXH@Z @ 22 NONAME ; public: void __thiscall TAskSaveDlgResponse::SetOkButton(int)
	?Username@TAuthenticationDlgRequest@@QBE?AVTPtrC16@@XZ @ 23 NONAME ; public: class TPtrC16  __thiscall TAuthenticationDlgRequest::Username(void)const 
	?Username@TAuthenticationDlgResponse@@QBE?AVTPtrC16@@XZ @ 24 NONAME ; public: class TPtrC16  __thiscall TAuthenticationDlgResponse::Username(void)const 

